%A MATLAB Toolbox
%
%Compression-based Texture Merging (CTM)
%
%Authors: John Wright, and Allen Y. Yang
%Contact: Allen Y. Yang <yang@eecs.berkeley.edu>
%
%(c) Copyright. University of California, Berkeley. 2007.
%
%Notice: The packages should NOT be used for any commercial purposes
%without direct consent of their author(s). The authors are not responsible
%for any potential property loss or damage caused directly or indirectly by
%the usage of the software.

function codingLength = coding_length(X, totalSampleCount, epsilon, affineModel);

[dimensionCount, sampleCount] = size(X);

epsilon2 = epsilon^2;

if affineModel==false
    codingLength = (dimensionCount + sampleCount)/2 * ...
        log2(det(eye(dimensionCount, dimensionCount) + X*X.' * dimensionCount / (sampleCount * epsilon2)))...
        -sampleCount*log2(sampleCount/totalSampleCount);
else
    meanX = mean(X')';
    X = X - repmat(meanX,1,sampleCount);
    codingLength = (dimensionCount + sampleCount)/2 * ...
        log2(det(eye(dimensionCount, dimensionCount) + X*X.' * dimensionCount / (sampleCount * epsilon2)))...
        -sampleCount*log2(sampleCount/totalSampleCount)+dimensionCount/2*log2(1+meanX.'*meanX/epsilon2);
end