%A MATLAB Toolbox
%
%Compression-based Texture Merging (CTM)
%
%Authors: John Wright, and Allen Y. Yang
%Contact: Allen Y. Yang <yang@eecs.berkeley.edu>
%
%(c) Copyright. University of California, Berkeley. 2007.
%
%Notice: The packages should NOT be used for any commercial purposes
%without direct consent of their author(s). The authors are not responsible
%for any potential property loss or damage caused directly or indirectly by
%the usage of the software.

function syntheticImage = generate_synthetic_image_segments(image, sampleLabels)

[imageX,imageY] = size(sampleLabels);
[imageX1, imageY1, imageDepth] = size(image);

if ((imageX1-imageX)~=(imageY1-imageY)) || (imageX1<imageX)
    error('The sizes of image and sampleLabels do not match.');
end

if (imageX1>imageX)
    halfWindowSize = (imageX1-imageX)/2;
    image = image(1+halfWindowSize:end-halfWindowSize,1+halfWindowSize:end-halfWindowSize,:);
end

syntheticImage=zeros(imageX*imageY,imageDepth);

image = double(image);
X = reshape(image,imageX*imageY,imageDepth);
segmentCount = max(max(sampleLabels));
for segmentIndex=1:segmentCount
    subsetXIndices = find(sampleLabels==segmentIndex);;
    subsetX=X(subsetXIndices,:);
    subsetXMean = mean(subsetX);
    syntheticImage(subsetXIndices,1:imageDepth)=repmat(subsetXMean,length(subsetXIndices),1);
end
warning off
syntheticImage=uint8(syntheticImage);
warning on
syntheticImage = reshape(syntheticImage,imageX,imageY,imageDepth);
