function I = segImage(I,S,varargin)

boundaryWidth = 1;
boundaryColor = 'red';

% Parse the optional inputs.
if (mod(length(varargin), 2) ~= 0 ),
    error(['Extra Parameters passed to the function ''' mfilename ''' must be passed in pairs.']);
end
parameterCount = length(varargin)/2;

for parameterIndex = 1:parameterCount,
    parameterName = varargin{parameterIndex*2 - 1};
    parameterValue = varargin{parameterIndex*2};
    switch lower(parameterName)
        case 'boundarycolor'
            boundaryColor = parameterValue;
        case 'boundarywidth'
            boundaryWidth = parameterValue;
        otherwise
            error('Invalid parameter');
    end
end

[cx,cy] = gradient(S);
ccc = (abs(cx)+abs(cy))~=0;

if boundaryWidth>1
    boundaryWidth = ceil(boundaryWidth);
    dilateWindow = ones(boundaryWidth, boundaryWidth);
    ccc = imdilate(ccc,dilateWindow);
elseif boundaryWidth<1
    warning('boundaryWidth has been reset to 1.');
end

if strcmp(boundaryColor,'red')
    I(:,:,1) = max(I(:,:,1),ccc);
    I(:,:,2) = min(I(:,:,2),~ccc);
    I(:,:,3) = min(I(:,:,3),~ccc);
elseif strcmp(boundaryColor,'black')
    I(:,:,1) = min(I(:,:,1),~ccc);
    I(:,:,2) = min(I(:,:,2),~ccc);
    I(:,:,3) = min(I(:,:,3),~ccc);
else
    warning('Does not recognize boundaryColor other than red and black');
    I(:,:,1) = max(I(:,:,1),~ccc);
    I(:,:,2) = max(I(:,:,2),~ccc);
    I(:,:,3) = max(I(:,:,3),~ccc);
end

I = mat2gray(I);