%A MATLAB Toolbox
%
%A test script for the lossy coding based image segmentor.
%
%This script computes the segmentation result using a single epsilon value.
%(meaning no adaptive gamma criterion)
%
%The implementation still uses adaptive process CTM_adaptive_segmentor.mat,
%but only provide a single epsilon candidate. Therefore, the segmentation
%terminates after the only epsilon is applied.
%
%The main parameter to tune: epsilon
%
%Authors: John Wright, and Allen Y. Yang
%Contact: Allen Y. Yang <yang@eecs.berkeley.edu>
%
%(c) Copyright. University of California, Berkeley. 2007.
%
%Notice: The packages should NOT be used for any commercial purposes
%without direct consent of their author(s). The authors are not responsible
%for any potential property loss or damage caused directly or indirectly by the usage of the software.


clear;
close all;
clc;

NORMALIZE_IMAGE = true;

imageName = '198023';

pathName = 'MDL-dataset/';
dataFilename = [pathName imageName '.mat'];
imageFullPath = [pathName imageName '.jpg'];

image = imread(imageFullPath);
[imageX,imageY,imageDepth] = size(image);
if NORMALIZE_IMAGE
    % Resize the image to 320*240
    imageSize = 320;
    if imageX>=imageY
        resizedImageY = round(imageY/imageX*imageSize);
        image = imresize(image,[imageSize,resizedImageY]);
    else
        resizedImageX = round(imageX/imageY*imageSize);
        image = imresize(image,[resizedImageX,imageSize]);
    end
end

windowSize = 7;
downsampleDimension = 8;
avoidBoundaryPixels = false;
saveSegmentationResult = false;
textureDifferenceMetric = 2;
epsilon = 0.05;
[pixelLabels, syntheticImage] = CTM_adaptive_segmentor(image,'windowSize', windowSize,...
    'downsampleDimension',downsampleDimension,'textureDifferenceMetric', textureDifferenceMetric,...
    'epsilonList',epsilon,...
    'avoidBoundaryPixels', avoidBoundaryPixels,'DEBUG',1,...
    'superpixelImageFilename',dataFilename,'readSuperpixelFile',true,'readSampleLabels',false,...
    'saveSegmentationResult',saveSegmentationResult);

figure(2);
set(gcf,'Color','white');
subplot(1,2,1);
syntheticImage = im2double(syntheticImage);
boundaryImage = segImage(syntheticImage,pixelLabels);
imshow(boundaryImage);
if saveSegmentationResult
    segmentationImageFilename = [pathName imageName '-result.png'];
    imwrite(boundaryImage,segmentationImageFilename);
end

subplot(1,2,2);
halfWindowSize = floor(windowSize/2);
syntheticImage = im2double(image);
syntheticImage = syntheticImage(1+halfWindowSize:end-halfWindowSize, 1+halfWindowSize:end-halfWindowSize,:);
syntheticImage(:,:,1) = brighten(syntheticImage(:,:,1),0.5);
syntheticImage(:,:,2) = brighten(syntheticImage(:,:,2),0.5);
syntheticImage(:,:,3) = brighten(syntheticImage(:,:,3),0.5);
boundaryImage = segImage(syntheticImage,pixelLabels,'boundaryColor','black','boundaryWidth',3);
imshow(boundaryImage);
if saveSegmentationResult
    overlapImageFilename = [pathName imageName '-gaussian.jpg'];
    imwrite(boundaryImage,overlapImageFilename);
end