%A MATLAB Toolbox
%
%Compression-based Texture Merging (CTM)
%
%Authors: John Wright, and Allen Y. Yang
%Contact: Allen Y. Yang <yang@eecs.berkeley.edu>
%
%(c) Copyright. University of California, Berkeley. 2007.
%
%Notice: The packages should NOT be used for any commercial purposes
%without direct consent of their author(s). The authors are not responsible
%for any potential property loss or damage caused directly or indirectly by
%the usage of the software.

function [vicinityMap,segmentRegistry]=vicinity_map(pixelLabels,isDirectedMap)
% vicinity_map computes vicinityMap and register pixels in each segment in
% segmentRegistry
%
% Note: the input parameter pixelLabels must have the dimension imageX*imageY.

if nargin==1
    % If true, only vicinityMap{i} only contains neighbors >i.
    % If false, vicinityMap{i} contains all neighbors.
    isDirectedMap = false;
end

offsetMatrix = [-1 -1 -1 0 0 1 1 1; -1 0 1 -1 1 -1 0 1];
[imageX, imageY] = size(pixelLabels);
segmentCount = max(max(pixelLabels));
segmentRegistry = cell(1,segmentCount);
vicinityMap = cell(1,segmentCount);

[xGradient,yGradient] = gradient(pixelLabels);
boundaryMap = (abs(xGradient)+abs(yGradient))~=0;

pixelIndex = 0;
for yIndex=1:imageY
    for xIndex=1:imageX
        
        pixelIndex = pixelIndex + 1;
        currentPixelLabel = pixelLabels(xIndex,yIndex);
        
        if boundaryMap(xIndex,yIndex)==true
            % update vicinityMap
            for offsetIndex=1:8
                xxIndex = xIndex + offsetMatrix(1,offsetIndex);
                yyIndex = yIndex + offsetMatrix(2,offsetIndex);
                if (xxIndex>0) & (xxIndex<=imageX) & (yyIndex>0) & (yyIndex<=imageY) & ...
                        (pixelLabels(xxIndex,yyIndex)~=currentPixelLabel) & ...
                        ((isDirectedMap==false) | (pixelLabels(xxIndex,yyIndex)>currentPixelLabel))
                        vicinityMap{currentPixelLabel} = union(vicinityMap{currentPixelLabel},pixelLabels(xxIndex,yyIndex));
                end
            end
        end
        
        segmentRegistry{currentPixelLabel}= [segmentRegistry{currentPixelLabel}, pixelIndex];
    end
end